@@ -199,18 +199,20 @@ func TestIAB(t *testing.T) {
 	if err != nil {
 		t.Fatalf("failed to get init's capabilities: %v", err)
 	}
-	iab := IABInit()
-	iab.Fill(Amb, one, Permitted)
+	iab := NewIAB()
+	if err := iab.Fill(Amb, one, Permitted); err != nil {
+		t.Fatalf("failed to fill Amb from Permitted: %v", err)
+	}
 	for i := 0; i < words; i++ {
 		if iab.i[i] != iab.a[i] {
-			t.Errorf("[%d] i=0x%08x != a=0x%08x", i, iab.i[i], iab.a[i])
+			t.Errorf("[%d: %q] i=0x%08x != a=0x%08x", i, one, iab.i[i], iab.a[i])
 		}
 	}
 	one.ClearFlag(Inheritable)
 	iab.Fill(Inh, one, Inheritable)
 	for i := 0; i < words; i++ {
 		if iab.i[i] != iab.a[i] {
-			t.Errorf("[%d] i=0x%08x != a=0x%08x", i, iab.i[i], iab.a[i])
+			t.Errorf("[%d: %q] i=0x%08x != a=0x%08x", i, one, iab.i[i], iab.a[i])
 		}
 	}
 
@@ -284,17 +286,3 @@ func TestFuncLaunch(t *testing.T) {
 		}
 	}
 }
-
-func TestFill(t *testing.T) {
-	c, err := FromText("cap_setfcap=p")
-	if err != nil {
-		t.Fatalf("failed to parse: %v", err)
-	}
-	c.Fill(Effective, Permitted)
-	c.ClearFlag(Permitted)
-	c.Fill(Inheritable, Effective)
-	c.ClearFlag(Effective)
-	if got, want := c.String(), "cap_setfcap=i"; got != want {
-		t.Errorf("Fill failed: got=%q want=%q", got, want)
-	}
-}
