@@ -29,7 +29,7 @@ index="${outdir}/index.md"
 function do_page () {
     m="$1"
     base="${m%.*}"
-    sect="${m#*.}"
+    sect="${m##*.}"
     output="${base}-${sect}.md"
 
     echo "converting ${m}" 1>&2
@@ -43,7 +43,7 @@ function do_page () {
 	return
     fi
 
-    pandoc -f man -t markdown < "${m}" | sed 's/\*\*\([^*]\+\)\*\*(\([138]\+\))/[\1(\2)](\1-\2.md)/g' > "${outdir}/${base}-${sect}.md"
+    pandoc -f man -t markdown < "${m}" | sed 's/\*\*\([^*]\+\)\*\*(\([1358]\+\))/[\1(\2)](\1-\2.md)/g' > "${outdir}/${base}-${sect}.md"
     echo "* [${base}(${sect})](${base}-${sect}.md)" >> "${index}"
 }
 
@@ -62,7 +62,7 @@ cat >> "${index}" <<EOF
 EOF
 
 # Assumes the m's are listed alphabetically.
-for n in 1 3 8 ; do
+for n in 1 3 5 7 8 ; do
 	cat >> "${index}" <<EOF
 
 ### Section ${n}
