@@ -19,7 +19,7 @@
 #include <unistd.h>
 
 #include "psx_syscall.h"
-#include "../psx/libpsx.h"
+#include "libpsx.h"
 
 /*
  * This is terrible, but some of the OS installed <asm/signal.h>
@@ -32,16 +32,29 @@
  * Coupled with the glibc suppression of access to the exact signal we
  * want to use, we have ended up just inlining all architecture
  * support here.
+ *
+ * To figure out all this stuff, I started with the following in the
+ * linux source tree:
+ *
+ *  mkdir -p junk/uapi
+ *  ln -s ../include/asm-generic ./junk/asm
+ *  ln -s ../../include/uapi/asm-generic ./junk/uapi/asm
+ *  a=arm ; gcc -I ./arch/$a/include -I ./arch/$a/include/generated \
+ *    -I ./include -I ./tools/include/generated/ -I ./junk \
+ *    -E ./include/uapi/linux/signal.h | less -psigaction
  */
 #if defined(__x86_64__) || defined(__i386__)	   \
     || defined(__arm__) || defined(__aarch64__)	   \
     || defined(__mips__) || defined(__loongarch__) \
-    || defined(__powerpc__) || defined(__s390__) || defined(__riscv)
+    || defined(__powerpc__) || defined(__s390__) || defined(__riscv) \
+    || defined(__alpha__) || defined(__hppa__) || defined(__sh__) \
+    || defined(__m68k__) || defined(__sparc__)
 
 #undef _NSIG
 #undef _NSIG_BPW
 #undef _NSIG_WORDS
 #undef SA_RESTORER
+#undef _HAS_SA_RESTORER
 #undef sa_handler
 #undef sa_sigaction
 
@@ -55,10 +68,22 @@
 #define _NSIG_WORDS  (_NSIG / _NSIG_BPW)
 
 #if defined(__x86_64__) || defined(__i386__) \
-    || defined(__arm__) || defined(__powerpc__)
+    || defined(__arm__) \
+    || defined(__powerpc__)
+/* field used */
 #define SA_RESTORER  0x04000000
 #endif /* architectures that use SA_RESTORER */
 
+#if defined(SA_RESTORER) \
+    || defined(__aarch64__) \
+    || defined(__m68k__) || defined(__sh__) || defined(__sparc__) \
+    || defined(__s390__) || defined(__sparc__)
+/* field defined */
+#define _HAS_SA_RESTORER   void *sa_restorer;
+#else
+#define _HAS_SA_RESTORER
+#endif /* architectures that include sa_restorer field */
+
 typedef struct {
     unsigned long sig[_NSIG_WORDS];
 } psx_sigset_t;
@@ -66,6 +91,12 @@ typedef struct {
 #define sigset_t psx_sigset_t
 
 struct psx_sigaction {
+#if defined(__m68k__) || defined(__alpha__)
+    void *sa_handler;
+    sigset_t sa_mask;
+    unsigned long sa_flags;
+    _HAS_SA_RESTORER
+#else /* ndef (__m68k__ or __alpha__) */
 #if defined(__mips__)
     unsigned long sa_flags;
     void *sa_handler;
@@ -73,10 +104,9 @@ struct psx_sigaction {
     void *sa_handler;
     unsigned long sa_flags;
 #endif
-#ifdef SA_RESTORER
-    void *sa_restorer;
-#endif
+    _HAS_SA_RESTORER
     sigset_t sa_mask;
+#endif /* def (__m68k__ or __alpha__) */
 };
 
 #define sigaction psx_sigaction
@@ -173,11 +203,6 @@ static void psx_posix_syscall_actor(int signum, siginfo_t *info, void *ignore) {
 	    __asm__ __volatile__("\npsx_restorer:\n\tli 0, 172\n\tsc\n");
 #else
 #error "unsupported architecture - https://bugzilla.kernel.org/show_bug.cgi?id=219687"
-	    /*
-	     * These are supported by go (go tool dist list | grep linux),
-	     * so we plan to also support them:
-	     *   linux/riscv64
-	     */
 #endif /* supported architectures */
 	}
 #endif /* def SA_RESTORER */
