@@ -8,6 +8,7 @@
 #include <stdlib.h>
 #include <sys/capability.h>
 #include <sys/psx_syscall.h>
+#include <sys/prctl.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
@@ -15,14 +16,18 @@
 static void *thread_fork_exit(void *data) {
     usleep(1234);
     pid_t pid = fork();
-    cap_t start = cap_get_proc();
-    if (start == NULL) {
+    long int start = cap_prctl(PR_GET_KEEPCAPS, 0, 0, 0, 0, 0);
+    if (start == -1) {
 	perror("FAILED: unable to start");
 	exit(1);
     }
     if (pid == 0) {
-	if (cap_set_proc(start)) {
-	    perror("setting empty caps failed");
+	if (cap_prctlw(PR_SET_KEEPCAPS, !start, 0, 0, 0, 0) != 0) {
+	    perror("failed to set proc");
+	    exit(1);
+	}
+	if (cap_prctlw(PR_GET_KEEPCAPS, 0, 0, 0, 0, 0) == start) {
+	    perror("failed to have set forked proc");
 	    exit(1);
 	}
 	exit(0);
@@ -33,8 +38,6 @@ static void *thread_fork_exit(void *data) {
 	       pid, res, errno);
 	exit(1);
     }
-    cap_set_proc(start);
-    cap_free(start);
     return NULL;
 }
 
@@ -42,22 +45,28 @@ int main(int argc, char **argv) {
     int i;
     printf("hello libcap and libpsx ");
     fflush(stdout);
-    cap_t start = cap_get_proc();
-    if (start == NULL) {
+    long int start = cap_prctl(PR_GET_KEEPCAPS, 0, 0, 0, 0, 0);
+    if (start == -1) {
 	perror("FAILED: to actually start");
 	exit(1);
     }
     pthread_t ignored[10];
     for (i = 0; i < 10; i++) {
 	pthread_create(&ignored[i], NULL, thread_fork_exit, NULL);
-    }
-    for (i = 0; i < 10; i++) {
 	printf(".");     /* because of fork, this may print double */
 	fflush(stdout);  /* try to limit the above effect */
-	if (cap_set_proc(start)) {
+	if (cap_prctlw(PR_SET_KEEPCAPS, i & 1, 0, 0, 0, 0)) {
 	    perror("failed to set proc");
 	    exit(1);
 	}
+	/*
+	 * This should validate all threads think the same thing,
+	 * and none of the fork() calls mess anything up.
+	 */
+	if (cap_prctlw(PR_GET_KEEPCAPS, 0, 0, 0, 0, 0) != (i & 1)) {
+	    perror("failed to have set proc");
+	    exit(1);
+	}
 	usleep(1000);
     }
     printf(" PASSED\n");
